# xLEAPP iOS Artifacts 

Provides iOS artifacts supported under [MIT license ](https://opensource.org/licenses/MIT).

This is not a standalone package. xLEAPP is required to be installed. See xLEAPP project documentation for information on using this plugins.